"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PeerDidResolver = void 0;
const DidPeer_1 = require("./DidPeer");
class PeerDidResolver {
    constructor(didDocumentRepository) {
        this.supportedMethods = ['peer'];
        this.didDocumentRepository = didDocumentRepository;
    }
    async resolve(did) {
        const didDocumentMetadata = {};
        try {
            const didPeer = DidPeer_1.DidPeer.fromDid(did);
            let didDocument;
            // For Method 1, retrieve from storage
            if (didPeer.numAlgo === 1 /* GenesisDoc */) {
                const didDocumentRecord = await this.didDocumentRepository.getById(did);
                didDocument = didDocumentRecord.didDocument;
            }
            else {
                didDocument = didPeer.didDocument;
            }
            return {
                didDocument,
                didDocumentMetadata,
                didResolutionMetadata: { contentType: 'application/did+ld+json' },
            };
        }
        catch (error) {
            return {
                didDocument: null,
                didDocumentMetadata,
                didResolutionMetadata: {
                    error: 'notFound',
                    message: `resolver_error: Unable to resolve did '${did}': ${error}`,
                },
            };
        }
    }
}
exports.PeerDidResolver = PeerDidResolver;
//# sourceMappingURL=PeerDidResolver.js.map